@@ -9,7 +9,7 @@ use version;
 use Carp ();
 use Module::Runtime 0.014 (); # bugfixes for use_package_optimistically
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 # $MODULES{$type}{$caller}{$mod} = [$min_version, $satisfied]
 my %MODULES;
@@ -43,7 +43,7 @@ sub has {
     my $caller = caller;
     my $spec   = $MODULES{$class}{$caller}{$mod};
 
-    return unless $spec;
+    return 0 unless $spec; # explicit to ensure a value even in list context
 
     if ( defined $ver ) {
         Carp::croak("module '$mod': '$ver' is not a valid version string")
@@ -81,7 +81,7 @@ recommended - Load recommended modules on demand when available
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
